---
comments: true
---

# Super Gobang

A backgammon game based on `tkintertools`.

* 🔖 项目版本: `2.0`
* 📦 框架版本: `tkintertools 2.6.21.1`
* ✏️ 项目作者: <https://github.com/Xiaokang2022>
* 🚀 项目存储库: <https://github.com/Xiaokang2022/Super-Gobang>

![关注](https://img.shields.io/github/watchers/Xiaokang2022/Super-Gobang?label=Watchers&logo=github&style=flat "关注")
![复刻](https://img.shields.io/github/forks/Xiaokang2022/Super-Gobang?label=Forks&logo=github&style=flat "复刻")
![星标](https://img.shields.io/github/stars/Xiaokang2022/Super-Gobang?label=Stars&color=gold&logo=github&style=flat "星标")
![议题](https://img.shields.io/github/issues/Xiaokang2022/Super-Gobang?label=Issues&logo=github&style=flat "议题")
![拉取请求](https://img.shields.io/github/issues-pr/Xiaokang2022/Super-Gobang?label=Pull%20Requests&logo=github&style=flat "拉取请求")
![讨论](https://img.shields.io/github/discussions/Xiaokang2022/Super-Gobang?label=Discussions&logo=github&style=flat "讨论")

![preview](https://github.com/Xiaokang2022/Super-Gobang/blob/main/preview.png?raw=true)
